%bcond_with bootstrap

Name:           xmlunit
Version:        2.9.1
Release:        %mkrel 2
Group:          Development/Java
Summary:        Provides classes to do asserts on xml
# The whole package is ASL 2.0 except for xmlunit-legacy which is BSD
License:        Apache-2.0
URL:            https://www.xmlunit.org/
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz
# Remove bundled binaries which cannot be easily verified for licensing
Source1:        generate-tarball.sh

Patch1:         0001-Disable-tests-requiring-network-access.patch
# This also solves the problem of tests requiring network. The files that would
# be fetched are identical to the local file
Patch2:         0002-Use-local-schema.patch
Patch3:         0003-Drop-support-for-JAXB.patch
Patch4:         0004-Port-to-assertj-core-3.patch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(net.bytebuddy:byte-buddy)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.assertj:assertj-core)
BuildRequires:  mvn(org.hamcrest:hamcrest-core)
BuildRequires:  mvn(org.hamcrest:hamcrest-library)
BuildRequires:  mvn(org.mockito:mockito-core)
%endif
BuildRequires:  jurand

%description
XMLUnit provides you with the tools to verify the XML you emit is the one you
want to create. It provides helpers to validate against an XML Schema, assert
the values of XPath queries or compare XML documents against expected outcomes.

%package        javadoc
Summary:        Javadoc for %{name}

%description    javadoc
Javadoc for %{name}

%package        assertj
Summary:        Assertj for %{name}

%description    assertj
This package provides %{summary}.

%package        core
Summary:        Core package for %{name}

%description    core
This package provides %{summary}.

%package        legacy
Summary:        Legacy package for %{name}
License:        BSD-3-Clause

%description    legacy
This package provides %{summary}.

%package        matchers
Summary:        Matchers for %{name}

%description    matchers
This package provides %{summary}.

%package        placeholders
Summary:        Placeholders for %{name}

%description    placeholders
This package provides %{summary}.

%prep
%setup -q -n %{name}-%{version}-src

%patch -P 1 -p1
%patch -P 2 -p1

%patch -P 3 -p1
rm -r xmlunit-core/src/main/java/org/xmlunit/builder/javax_jaxb\
 xmlunit-core/src/main/java/org/xmlunit/builder/JaxbBuilderFactory.java\
 xmlunit-core/src/main/java/org/xmlunit/builder/JaxbBuilderFactoryLocator.java\
 xmlunit-core/src/test/java/org/xmlunit/builder/javax_jaxb\
;

%patch -P 4 -p1

# Port to hamcrest 2.1
%java_remove_annotations xmlunit-matchers -p org[.]hamcrest[.]Factory

%pom_disable_module xmlunit-assertj
%pom_disable_module xmlunit-jakarta-jaxb-impl

%pom_remove_plugin org.codehaus.mojo:buildnumber-maven-plugin
%pom_remove_plugin :maven-assembly-plugin
%pom_remove_plugin -r :maven-shade-plugin
%pom_remove_plugin -r org.cyclonedx:cyclonedx-maven-plugin

%mvn_alias org.xmlunit:xmlunit-legacy xmlunit:xmlunit
%mvn_alias org.xmlunit:xmlunit-assertj3 org.xmlunit:xmlunit-assertj

# JAXB and JAF are not available in JDK11
%pom_remove_dep org.glassfish.jaxb: xmlunit-core
%pom_remove_dep jakarta.xml.bind: xmlunit-core
rm -rf xmlunit-core/src/{main,test}/java/org/xmlunit/builder/{jaxb/,JaxbBuilder.java,JaxbBuilderTest.java}

%build
%mvn_build -s -- -Dmaven.compile.source=1.8 -Dmaven.compile.target=1.8

%install
%mvn_install

%files -f .mfiles-xmlunit-parent
%doc README.md CONTRIBUTING.md RELEASE_NOTES.md
%license LICENSE

%files javadoc -f .mfiles-javadoc
%files assertj -f .mfiles-xmlunit-assertj3
%files core -f .mfiles-xmlunit-core
%files legacy -f .mfiles-xmlunit-legacy
%files matchers -f .mfiles-xmlunit-matchers
%files placeholders -f .mfiles-xmlunit-placeholders


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 2.9.1-2.mga10
+ Revision: 2223814
- Mageia 10 Mass Rebuild

* Sun May 26 2024 daviddavid <daviddavid> 2.9.1-1.mga10
+ Revision: 2067708
- Update to upstream version 2.9.1
- Rebuilt for java-21-openjdk as system jdk

* Mon Jul 25 2022 neoclust <neoclust> 2.8.2-4.mga9
+ Revision: 1871445
- Disable bootstrap

* Mon Jul 25 2022 neoclust <neoclust> 2.8.2-3.mga9
+ Revision: 1870974
- Fix bootstrap
- New version 2.8.2
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Sep 10 2020 daviddavid <daviddavid> 0:2.7.0-1.mga8
+ Revision: 1624224
- Update to version 2.7.0
- Allow building against JDK 11
- Rebuilt for JDK-11

* Sun Feb 16 2020 umeabot <umeabot> 0:2.6.3-2.mga8
+ Revision: 1536138
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 0:2.6.3-1.mga8
+ Revision: 1453319
- Update to version 2.6.3

* Fri Sep 21 2018 umeabot <umeabot> 0:1.6-6.mga7
+ Revision: 1292172
- Mageia 7 Mass Rebuild

* Sat Sep 02 2017 daviddavid <daviddavid> 0:1.6-5.mga7
+ Revision: 1150842
- Install with XMvn (sync with fc27)
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 0:1.6-3.mga6
+ Revision: 978241
- First rebuild of the java stack

* Fri Feb 19 2016 umeabot <umeabot> 0:1.6-2.mga6
+ Revision: 968911
- Mageia 6 Mass Rebuild

* Sat Jul 25 2015 tv <tv> 0:1.6-1.mga6
+ Revision: 857459
- new release

* Wed Oct 15 2014 umeabot <umeabot> 0:1.5-4.mga5
+ Revision: 745006
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:1.5-3.mga5
+ Revision: 690718
- Mageia 5 Mass Rebuild

* Sun Sep 07 2014 spuhler <spuhler> 0:1.5-2.mga5
+ Revision: 673372
- spec file synced with Fedora

* Sun Sep 07 2014 spuhler <spuhler> 0:1.5-1.mga5
+ Revision: 673030
- upgrade to version 1.5

* Mon Jan 06 2014 dmorgan <dmorgan> 0:1.3-7.mga4
+ Revision: 565231
- Rebuild with fixed rpms macros

* Tue Dec 10 2013 joequant <joequant> 0:1.3-6.mga4
+ Revision: 556098
- fix pom location
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Tue Jul 30 2013 joequant <joequant> 0:1.3-4.mga4
+ Revision: 460907
- remove ant-trax dep

* Mon Jan 14 2013 umeabot <umeabot> 0:1.3-3.mga3
+ Revision: 387218
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jun 24 2012 dmorgan <dmorgan> 0:1.3-2.mga3
+ Revision: 263301
- Sync with fedora spec file
- Fix docbook use
+ gil <gil>
- BR docbook-dtds
- update to 1.3
  added docbook5-style-xsl support
  removed unsused gcj macro

* Tue Jan 25 2011 dmorgan <dmorgan> 0:1.2-2.0.2.mga1
+ Revision: 39628
- imported package xmlunit


* Wed Sep 09 2009 Thierry Vignaud <tvignaud@mandriva.com> 0:1.2-2.0.2mdv2010.0
+ Revision: 435155
- rebuild

* Sat Aug 09 2008 Thierry Vignaud <tvignaud@mandriva.com> 0:1.2-2.0.1mdv2009.0
+ Revision: 269800
- rebuild early 2009.0 package (before pixel changes)

* Fri Jun 13 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:1.2-0.0.1mdv2009.0
+ Revision: 218670
- new version 1.2 and disable gcj compile

* Tue Feb 26 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:1.1-0.0.1mdv2008.1
+ Revision: 175331
- new version, spec cleanup, use pom from the tar

* Mon Jan 07 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:1.0-5.0.1mdv2008.1
+ Revision: 146299
- add ant-trax BR
- fix Group
- import xmlunit


